summaryrefslogtreecommitdiff
path: root/configmgr/source
diff options
context:
space:
mode:
authorLars Langhans <lla@openoffice.org>2001-01-26 14:01:57 +0000
committerLars Langhans <lla@openoffice.org>2001-01-26 14:01:57 +0000
commit6f863ec2c6a3918a3e8800f68ec148b2c8a232dc (patch)
treea0acb0f23af6fb31fcdfdb103669d2a60face967 /configmgr/source
parentbb51c6390b32ab0770aad3f8e284e129602e68eb (diff)
#82734# rename lasy to lazy
Diffstat (limited to 'configmgr/source')
-rw-r--r--configmgr/source/api2/confproviderimpl2.cxx20
-rw-r--r--configmgr/source/api2/providerimpl.cxx18
-rw-r--r--configmgr/source/inc/options.hxx14
3 files changed, 26 insertions, 26 deletions
diff --git a/configmgr/source/api2/confproviderimpl2.cxx b/configmgr/source/api2/confproviderimpl2.cxx
index 1922b7c330ea..f4413ebddea7 100644
--- a/configmgr/source/api2/confproviderimpl2.cxx
+++ b/configmgr/source/api2/confproviderimpl2.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: confproviderimpl2.cxx,v $
*
- * $Revision: 1.18 $
+ * $Revision: 1.19 $
*
- * last change: $Author: lla $ $Date: 2001-01-26 07:54:18 $
+ * last change: $Author: lla $ $Date: 2001-01-26 15:01:54 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -129,9 +129,9 @@ namespace configmgr
::rtl::OUString sUser, sPath, sLocale;
sal_Int32 nLevels;
bool bNoCache;
- bool bLasyWrite; // no need here
+ bool bLazyWrite; // no need here
- OProviderImpl::FactoryArguments::extractArgs(aArgs, sPath, sUser, sLocale, nLevels, bNoCache, bLasyWrite);
+ OProviderImpl::FactoryArguments::extractArgs(aArgs, sPath, sUser, sLocale, nLevels, bNoCache, bLazyWrite);
vos::ORef<OOptions> xOptions = new OOptions(getDefaultOptions());
@@ -206,17 +206,17 @@ namespace configmgr
::rtl::OUString sUser, sPath, sLocale;
sal_Int32 nLevels;
bool bNoCache;
- bool bLasyWrite;
+ bool bLazyWrite;
- OProviderImpl::FactoryArguments::extractArgs(aArgs, sPath, sUser, sLocale, nLevels, bNoCache, bLasyWrite);
-#ifdef DEBUG
+ OProviderImpl::FactoryArguments::extractArgs(aArgs, sPath, sUser, sLocale, nLevels, bNoCache, bLazyWrite);
+#ifdef LLA_PRIVAT_DEBUG
// HACK for Test only
ConfigurationName aName(sPath);
if (!aName.isEmpty() && aName.moduleName().equalsIgnoreCase(ASCII("org.openoffice.Office.Common")))
{
- // bLasyWrite = true;
+ // bLazyWrite = true;
}
- bLasyWrite = true;
+ bLazyWrite = true;
#endif
vos::ORef<OOptions> xOptions = new OOptions(getDefaultOptions());
@@ -249,7 +249,7 @@ namespace configmgr
if (sLocale.getLength()) xOptions->setLocale(sLocale);
if (bNoCache) xOptions->setNoCache(bNoCache);
- if (bLasyWrite) xOptions->setLasyWrite(bLasyWrite);
+ if (bLazyWrite) xOptions->setLazyWrite(bLazyWrite);
CFG_TRACE_INFO_NI("config provider: node accessor extracted from the args is %s", OUSTRING2ASCII(sPath));
CFG_TRACE_INFO_NI("config provider: level depth extracted from the args is %i", nLevels);
diff --git a/configmgr/source/api2/providerimpl.cxx b/configmgr/source/api2/providerimpl.cxx
index 14b8b63464e8..dd8010ca6e62 100644
--- a/configmgr/source/api2/providerimpl.cxx
+++ b/configmgr/source/api2/providerimpl.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: providerimpl.cxx,v $
*
- * $Revision: 1.19 $
+ * $Revision: 1.20 $
*
- * last change: $Author: lla $ $Date: 2001-01-26 07:54:19 $
+ * last change: $Author: lla $ $Date: 2001-01-26 15:01:54 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -458,7 +458,7 @@ namespace configmgr
rtl::OUString OProviderImpl::FactoryArguments::sDepth(ASCII("depth"));
rtl::OUString OProviderImpl::FactoryArguments::sLocale(ASCII("locale"));
rtl::OUString OProviderImpl::FactoryArguments::sNoCache(ASCII("nocache"));
- rtl::OUString OProviderImpl::FactoryArguments::sLasyWrite(ASCII("lasywrite"));
+ rtl::OUString OProviderImpl::FactoryArguments::sLazyWrite(ASCII("lazywrite"));
#ifdef DBG_UTIL
//-----------------------------------------------------------------------------
@@ -473,7 +473,7 @@ namespace configmgr
aArgs.insert(OProviderImpl::FactoryArguments::sDepth);
aArgs.insert(OProviderImpl::FactoryArguments::sLocale);
aArgs.insert(OProviderImpl::FactoryArguments::sNoCache);
- aArgs.insert(OProviderImpl::FactoryArguments::sLasyWrite);
+ aArgs.insert(OProviderImpl::FactoryArguments::sLazyWrite);
}
HashSet::const_iterator it = aArgs.find(rName);
@@ -521,7 +521,7 @@ namespace configmgr
OUString& /* [out] */ _rLocale,
sal_Int32& /* [out] */ _nLevels,
bool& /* [out] */ _bNoCache,
- bool& /* [out] */ _bLasyWrite)
+ bool& /* [out] */ _bLazyWrite)
throw (lang::IllegalArgumentException)
{
@@ -531,7 +531,7 @@ namespace configmgr
::rtl::OUString sUser, sPath, sLocale;
sal_Int32 nLevelDepth = ITreeProvider::ALL_LEVELS;
sal_Bool bNoCache = sal_False;
- sal_Bool bLasyWrite = sal_False;
+ sal_Bool bLazyWrite = sal_False;
// the args have to be a sequence of property values, currently three property names are recognized
beans::PropertyValue aCurrent;
@@ -552,8 +552,8 @@ namespace configmgr
bExtractSuccess = (aCurrent.Value >>= sLocale);
else if (aCurrent.Name.equalsIgnoreCase(OProviderImpl::FactoryArguments::sNoCache))
bExtractSuccess = (aCurrent.Value >>= bNoCache);
- else if (aCurrent.Name.equalsIgnoreCase(OProviderImpl::FactoryArguments::sLasyWrite))
- bExtractSuccess = (aCurrent.Value >>= bLasyWrite);
+ else if (aCurrent.Name.equalsIgnoreCase(OProviderImpl::FactoryArguments::sLazyWrite))
+ bExtractSuccess = (aCurrent.Value >>= bLazyWrite);
/*
#ifdef DBG_UTIL
else
@@ -603,7 +603,7 @@ namespace configmgr
_rLocale = sLocale;
_rUser = sUser;
_bNoCache = (bNoCache != sal_False);
- _bLasyWrite = bLasyWrite;
+ _bLazyWrite = bLazyWrite;
}
// class OOptions
//..........................................................................
diff --git a/configmgr/source/inc/options.hxx b/configmgr/source/inc/options.hxx
index 083892be67c9..9c35bf1ec7c8 100644
--- a/configmgr/source/inc/options.hxx
+++ b/configmgr/source/inc/options.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: options.hxx,v $
*
- * $Revision: 1.8 $
+ * $Revision: 1.9 $
*
- * last change: $Author: lla $ $Date: 2001-01-26 07:53:36 $
+ * last change: $Author: lla $ $Date: 2001-01-26 15:01:57 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -98,12 +98,12 @@ namespace configmgr
rtl::OUString m_sUser; // user key used (could be empty)
rtl::OUString m_sDefaultUser; // user key used (could be empty)
sal_Int32 m_nCacheID; // set if data should not be fetched from the cache, but reloaded
- bool m_bLasyWrite; // true, if tree use lasy writing
+ bool m_bLazyWrite; // true, if tree use lazy writing
public:
OOptions(const uno::Reference< script::XTypeConverter >& _xConverter)
:m_xConverter(_xConverter)
,m_nCacheID(0)
- ,m_bLasyWrite(false)
+ ,m_bLazyWrite(false)
{}
OOptions(const OOptions& _rOptions)
@@ -113,7 +113,7 @@ namespace configmgr
,m_sLocale(_rOptions.m_sLocale)
,m_sUser(_rOptions.m_sUser)
,m_nCacheID(0), // cache identity is not copied
- m_bLasyWrite(_rOptions.m_bLasyWrite)
+ m_bLazyWrite(_rOptions.m_bLazyWrite)
{
if (!_rOptions.canUseCache()) this->setNoCache();
}
@@ -135,8 +135,8 @@ namespace configmgr
void setDefaultUser(const rtl::OUString& _rUser) {m_sDefaultUser = _rUser;}
void setLocale(const rtl::OUString& _rLocale) {m_sLocale = _rLocale;}
void setDefaultLocale(const rtl::OUString& _rLocale) {m_sDefaultLocale = _rLocale;}
- void setLasyWrite(bool _bLasyWrite = false) {m_bLasyWrite = _bLasyWrite;}
- bool getLasyWrite() {return m_bLasyWrite;}
+ void setLazyWrite(bool _bLazyWrite = false) {m_bLazyWrite = _bLazyWrite;}
+ bool getLazyWrite() {return m_bLazyWrite;}
friend sal_Int32 compareCacheIdentity(OOptions const& lhs, OOptions const& rhs)
{ return rhs.m_nCacheID - lhs.m_nCacheID; }